Module: Arango::Database::ViewAccess
- Included in:
- Arango::Database
- Defined in:
- lib/arango/database/view_access.rb
Instance Method Summary collapse
- #create_search_view ⇒ Object
- #create_view ⇒ Object
- #list_views ⇒ Object
- #search_view(name) ⇒ Object
-
#view(name) ⇒ Object
not found.
-
#views ⇒ Object
verified, in js api.
Instance Method Details
#create_search_view ⇒ Object
4 5 6 |
# File 'lib/arango/database/view_access.rb', line 4 def create_search_view # TODO end |
#create_view ⇒ Object
30 31 32 |
# File 'lib/arango/database/view_access.rb', line 30 def create_view end |
#list_views ⇒ Object
12 13 14 |
# File 'lib/arango/database/view_access.rb', line 12 def list_views # TODO Fetches all views from the database and returns an array of view descriptions. end |
#search_view(name) ⇒ Object
8 9 10 |
# File 'lib/arango/database/view_access.rb', line 8 def search_view(name) # TODO Returns a ArangoSearchView instance for the given view name end |
#view(name) ⇒ Object
not found
26 27 28 |
# File 'lib/arango/database/view_access.rb', line 26 def view(name) Arango::View.new(database: self, name: name) end |
#views ⇒ Object
verified, in js api
17 18 19 20 21 22 23 |
# File 'lib/arango/database/view_access.rb', line 17 def views result = request("GET", "_api/view", key: :result) return result if return_directly?(result) result.map do |view| Arango::View.new(database: self, id: view[:id], name: view[:name], type: view[:type]) end end |